<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>HideAllBlocks</name>
    <message>
        <source>&amp;Hide All</source>
        <translation type="vanished">全部隐藏(&amp;H)</translation>
    </message>
    <message>
        <location filename="../HideAllBlocksInit.js" line="+2"/>
        <source>&amp;Hide All Blocks</source>
        <translation>隐藏全部块(&amp;H)</translation>
    </message>
</context>
</TS>
